@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: conf.h 13625 2012-12-05 17:29:46Z jordan $
+ * $Id: conf.h 13683 2012-12-22 20:35:19Z jordan $
  *
  * Copyright (c) Transmission authors and contributors
  *
@@ -26,23 +26,24 @@
 #define GTR_CONFIG_H
 
 #include <inttypes.h>
-#include <libtransmission/transmission.h> /* tr_benc, tr_session */
+#include <libtransmission/transmission.h> /* tr_variant, tr_session */
+#include <libtransmission/quark.h>
 
-void             gtr_pref_init            (const char * config_dir);
+void                gtr_pref_init            (const char * config_dir);
 
-int64_t          gtr_pref_int_get         (const char * key);
-void             gtr_pref_int_set         (const char * key, int64_t value);
+int64_t             gtr_pref_int_get         (const tr_quark key);
+void                gtr_pref_int_set         (const tr_quark key, int64_t value);
 
-double           gtr_pref_double_get      (const char * key);
-void             gtr_pref_double_set      (const char * key, double value);
+double              gtr_pref_double_get      (const tr_quark key);
+void                gtr_pref_double_set      (const tr_quark key, double value);
 
-gboolean         gtr_pref_flag_get        (const char * key);
-void             gtr_pref_flag_set        (const char * key, gboolean value);
+gboolean            gtr_pref_flag_get        (const tr_quark key);
+void                gtr_pref_flag_set        (const tr_quark key, gboolean value);
 
-const char*      gtr_pref_string_get      (const char * key);
-void             gtr_pref_string_set      (const char * key, const char * value);
+const char*         gtr_pref_string_get      (const tr_quark key);
+void                gtr_pref_string_set      (const tr_quark key, const char * value);
 
-void             gtr_pref_save            (tr_session *);
-struct tr_benc*  gtr_pref_get_all         (void);
+void                gtr_pref_save            (tr_session *);
+struct tr_variant*  gtr_pref_get_all         (void);
 
 #endif /* GTR_CONFIG_H */
