@@ -1,15 +1,13 @@
 /*
- * This file Copyright (C) Mnemosyne LLC
+ * This file Copyright (C) 2007-2014 Mnemosyne LLC
  *
- * This file is licensed by the GPL version 2. Works owned by the
- * Transmission project are granted a special exemption to clause 2 (b)
- * so that the bulk of its code can remain under the MIT license.
- * This exemption does not extend to derived works not owned by
- * the Transmission project.
+ * It may be used under the GNU GPL versions 2 or 3
+ * or any future license endorsed by Mnemosyne LLC.
  *
- * $Id: details.c 14018 2013-02-14 15:17:42Z jordan $
+ * $Id: details.c 14241 2014-01-21 03:10:30Z jordan $
  */
 
+#include <limits.h> /* INT_MAX */
 #include <stddef.h>
 #include <stdio.h> /* sscanf () */
 #include <stdlib.h> /* abort () */
@@ -1053,16 +1051,16 @@ info_page_new (struct DetailsImpl * di)
     gtk_label_set_single_line_mode (GTK_LABEL (l), TRUE);
     hig_workarea_add_row (t, &row, _("Have:"), l, NULL);
 
-    /* downloaded */
-    l = di->dl_lb = gtk_label_new (NULL);
-    gtk_label_set_single_line_mode (GTK_LABEL (l), TRUE);
-    hig_workarea_add_row (t, &row, _("Downloaded:"), l, NULL);
-
     /* uploaded */
     l = di->ul_lb = gtk_label_new (NULL);
     gtk_label_set_single_line_mode (GTK_LABEL (l), TRUE);
     hig_workarea_add_row (t, &row, _("Uploaded:"), l, NULL);
 
+    /* downloaded */
+    l = di->dl_lb = gtk_label_new (NULL);
+    gtk_label_set_single_line_mode (GTK_LABEL (l), TRUE);
+    hig_workarea_add_row (t, &row, _("Downloaded:"), l, NULL);
+
     /* state */
     l = di->state_lb = gtk_label_new (NULL);
     gtk_label_set_single_line_mode (GTK_LABEL (l), TRUE);
