@@ -1,17 +1,14 @@
 /*
- * This file Copyright (C) Mnemosyne LLC
+ * This file Copyright (C) 2007-2014 Mnemosyne LLC
  *
- * This file is licensed by the GPL version 2. Works owned by the
- * Transmission project are granted a special exemption to clause 2 (b)
- * so that the bulk of its code can remain under the MIT license.
- * This exemption does not extend to derived works not owned by
- * the Transmission project.
+ * It may be used under the GNU GPL versions 2 or 3
+ * or any future license endorsed by Mnemosyne LLC.
  *
- * $Id: tr-prefs.c 14149 2013-07-27 18:20:32Z jordan $
+ * $Id: tr-prefs.c 14241 2014-01-21 03:10:30Z jordan $
  */
 
 #include <ctype.h> /* isspace */
-#include <limits.h> /* USHRT_MAX */
+#include <limits.h> /* USHRT_MAX, INT_MAX */
 #include <unistd.h>
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
