@@ -1,17 +1,15 @@
 /*
- * This file Copyright (C) Mnemosyne LLC
+ * This file Copyright (C) 2008-2014 Mnemosyne LLC
  *
- * This file is licensed by the GPL version 2. Works owned by the
- * Transmission project are granted a special exemption to clause 2 (b)
- * so that the bulk of its code can remain under the MIT license.
- * This exemption does not extend to derived works not owned by
- * the Transmission project.
+ * It may be used under the GNU GPL versions 2 or 3
+ * or any future license endorsed by Mnemosyne LLC.
  *
- * $Id: util.c 14143 2013-07-24 17:11:21Z jordan $
+ * $Id: util.c 14241 2014-01-21 03:10:30Z jordan $
  */
 
 #include <ctype.h> /* isxdigit () */
 #include <errno.h>
+#include <limits.h> /* INT_MAX */
 #include <stdarg.h>
 #include <string.h> /* strchr (), strrchr (), strlen (), strstr () */
 
