@@ -1,13 +1,10 @@
 /*
- * This file Copyright (C) Mnemosyne LLC
+ * This file Copyright (C) 2010-2014 Mnemosyne LLC
  *
- * This file is licensed by the GPL version 2. Works owned by the
- * Transmission project are granted a special exemption to clause 2 (b)
- * so that the bulk of its code can remain under the MIT license.
- * This exemption does not extend to derived works not owned by
- * the Transmission project.
+ * It may be used under the GNU GPL versions 2 or 3
+ * or any future license endorsed by Mnemosyne LLC.
  *
- * $Id: announcer-common.h 13902 2013-01-30 20:00:43Z jordan $
+ * $Id: announcer-common.h 14241 2014-01-21 03:10:30Z jordan $
  */
 
 #ifndef __LIBTRANSMISSION_ANNOUNCER_MODULE___
@@ -96,8 +93,8 @@ typedef struct
 }
 tr_scrape_response;
 
-typedef void tr_scrape_response_func (const tr_scrape_response  * response,
-                                      void                      * user_data);
+typedef void (*tr_scrape_response_func) (const tr_scrape_response  * response,
+                                         void                      * user_data);
 
 void tr_tracker_http_scrape (tr_session               * session,
                              const tr_scrape_request  * req,
@@ -223,8 +220,8 @@ typedef struct
 }
 tr_announce_response;
 
-typedef void tr_announce_response_func (const tr_announce_response * response,
-                                        void                       * userdata);
+typedef void (*tr_announce_response_func) (const tr_announce_response * response,
+                                           void                       * userdata);
 
 void tr_tracker_http_announce (tr_session                 * session,
                                const tr_announce_request  * req,
