@@ -1,13 +1,10 @@
 /*
- * This file Copyright (C) Mnemosyne LLC
+ * This file Copyright (C) 2010-2014 Mnemosyne LLC
  *
- * This file is licensed by the GPL version 2. Works owned by the
- * Transmission project are granted a special exemption to clause 2 (b)
- * so that the bulk of its code can remain under the MIT license.
- * This exemption does not extend to derived works not owned by
- * the Transmission project.
+ * It may be used under the GNU GPL versions 2 or 3
+ * or any future license endorsed by Mnemosyne LLC.
  *
- * $Id: announcer.c 14138 2013-07-21 21:11:54Z jordan $
+ * $Id: announcer.c 14241 2014-01-21 03:10:30Z jordan $
  */
 
 #include <assert.h>
@@ -159,7 +156,7 @@ tr_announcerHasBacklog (const struct tr_announcer * announcer)
 }
 
 static void
-onUpkeepTimer (int foo UNUSED, short bar UNUSED, void * vannouncer);
+onUpkeepTimer (evutil_socket_t foo UNUSED, short bar UNUSED, void * vannouncer);
 
 void
 tr_announcerInit (tr_session * session)
@@ -407,7 +404,7 @@ typedef struct tr_torrent_tiers
     tr_tracker * trackers;
     int tracker_count;
 
-    tr_tracker_callback * callback;
+    tr_tracker_callback callback;
     void * callbackData;
 }
 tr_torrent_tiers;
@@ -481,7 +478,7 @@ publishMessage (tr_tier * tier, const char * msg, int type)
         if (tier->currentTracker)
             event.tracker = tier->currentTracker->announce;
 
-        tiers->callback (tier->tor, &event, tiers->callbackData);
+        (*tiers->callback) (tier->tor, &event, tiers->callbackData);
     }
 }
 
@@ -533,7 +530,7 @@ publishPeersPex (tr_tier * tier, int seeds, int leechers,
         e.pexCount = n;
         dbgmsg (tier, "got %d peers; seed prob %d", n, (int)e.seedProbability);
 
-        tier->tor->tiers->callback (tier->tor, &e, NULL);
+        (*tier->tor->tiers->callback) (tier->tor, &e, NULL);
     }
 }
 
@@ -691,7 +688,7 @@ addTorrentToTier (tr_torrent_tiers * tt, tr_torrent * tor)
 
 tr_torrent_tiers *
 tr_announcerAddTorrent (tr_torrent           * tor,
-                        tr_tracker_callback  * callback,
+                        tr_tracker_callback    callback,
                         void                 * callbackData)
 {
     tr_torrent_tiers * tiers;
@@ -919,12 +916,12 @@ announce_request_new (const tr_announcer  * announcer,
     req->down = tier->byteCounts[TR_ANN_DOWN];
     req->corrupt = tier->byteCounts[TR_ANN_CORRUPT];
     req->leftUntilComplete = tr_torrentHasMetadata (tor)
-            ? tor->info.totalSize - tr_cpHaveTotal (&tor->completion)
+            ? tor->info.totalSize - tr_torrentHaveTotal (tor)
             : ~ (uint64_t)0;
     req->event = event;
     req->numwant = event == TR_ANNOUNCE_EVENT_STOPPED ? 0 : NUMWANT;
     req->key = announcer->key;
-    req->partial_seed = tr_cpGetStatus (&tor->completion) == TR_PARTIAL_SEED;
+    req->partial_seed = tr_torrentGetCompleteness (tor) == TR_PARTIAL_SEED;
     tier_build_log_name (tier, req->log_name, sizeof (req->log_name));
     return req;
 }
@@ -1035,8 +1032,8 @@ on_announce_done (const tr_announce_response  * response,
                       "interval:%d "
                       "min_interval:%d "
                       "tracker_id_str:%s "
-                      "pex:%zu "
-                      "pex6:%zu "
+                      "pex:%"TR_PRIuSIZE" "
+                      "pex6:%"TR_PRIuSIZE" "
                       "err:%s "
                       "warn:%s",
                     (int)response->did_connect,
@@ -1200,7 +1197,7 @@ announce_request_free (tr_announce_request * req)
 static void
 announce_request_delegate (tr_announcer               * announcer,
                            tr_announce_request        * request,
-                           tr_announce_response_func  * callback,
+                           tr_announce_response_func    callback,
                            void                       * callback_data)
 {
     tr_session * session = announcer->session;
@@ -1287,8 +1284,8 @@ on_scrape_error (tr_session * session, tr_tier * tier, const char * errmsg)
 
     /* schedule a rescrape */
     interval = getRetryInterval (tier->currentTracker);
-    dbgmsg (tier, "Retrying scrape in %zu seconds.", (size_t)interval);
-    tr_logAddTorInfo (tier->tor, "Retrying scrape in %zu seconds.", (size_t)interval);
+    dbgmsg (tier, "Retrying scrape in %"TR_PRIuSIZE" seconds.", (size_t)interval);
+    tr_logAddTorInfo (tier->tor, "Retrying scrape in %"TR_PRIuSIZE" seconds.", (size_t)interval);
     tier->lastScrapeSucceeded = false;
     tier->scrapeAt = get_next_scrape_time (session, tier, interval);
 }
@@ -1397,7 +1394,7 @@ on_scrape_done (const tr_scrape_response * response, void * vsession)
 static void
 scrape_request_delegate (tr_announcer             * announcer,
                          const tr_scrape_request  * request,
-                         tr_scrape_response_func  * callback,
+                         tr_scrape_response_func    callback,
                          void                     * callback_data)
 {
     tr_session * session = announcer->session;
@@ -1566,7 +1563,7 @@ announceMore (tr_announcer * announcer)
 }
 
 static void
-onUpkeepTimer (int foo UNUSED, short bar UNUSED, void * vannouncer)
+onUpkeepTimer (evutil_socket_t foo UNUSED, short bar UNUSED, void * vannouncer)
 {
     tr_announcer * announcer = vannouncer;
     tr_session * session = announcer->session;
