@@ -1,13 +1,10 @@
 /*
- * This file Copyright (C) Mnemosyne LLC
+ * This file Copyright (C) 2010-2014 Mnemosyne LLC
  *
- * This file is licensed by the GPL version 2. Works owned by the
- * Transmission project are granted a special exemption to clause 2 (b)
- * so that the bulk of its code can remain under the MIT license.
- * This exemption does not extend to derived works not owned by
- * the Transmission project.
+ * It may be used under the GNU GPL versions 2 or 3
+ * or any future license endorsed by Mnemosyne LLC.
  *
- * $Id: announcer.h 13625 2012-12-05 17:29:46Z jordan $
+ * $Id: announcer.h 14241 2014-01-21 03:10:30Z jordan $
  */
 
 #ifndef __TRANSMISSION__
@@ -56,9 +53,9 @@ typedef struct
 }
 tr_tracker_event;
 
-typedef void tr_tracker_callback (tr_torrent              * tor,
-                                   const tr_tracker_event  * event,
-                                   void                    * client_data);
+typedef void (*tr_tracker_callback) (tr_torrent              * tor,
+                                     const tr_tracker_event  * event,
+                                     void                    * client_data);
 
 /**
 ***  Session ctor/dtor
@@ -73,7 +70,7 @@ void tr_announcerClose (tr_session *);
 **/
 
 struct tr_torrent_tiers * tr_announcerAddTorrent (tr_torrent          * torrent,
-                                                  tr_tracker_callback * cb,
+                                                  tr_tracker_callback   cb,
                                                   void                * cbdata);
 
 bool tr_announcerHasBacklog (const struct tr_announcer *);
