@@ -1,13 +1,10 @@
 /*
- * This file Copyright (C) Mnemosyne LLC
+ * This file Copyright (C) 2007-2014 Mnemosyne LLC
  *
- * This file is licensed by the GPL version 2. Works owned by the
- * Transmission project are granted a special exemption to clause 2 (b)
- * so that the bulk of its code can remain under the MIT license.
- * This exemption does not extend to derived works not owned by
- * the Transmission project.
+ * It may be used under the GNU GPL versions 2 or 3
+ * or any future license endorsed by Mnemosyne LLC.
  *
- * $Id: handshake.c 14155 2013-08-05 04:39:43Z jordan $
+ * $Id: handshake.c 14241 2014-01-21 03:10:30Z jordan $
  */
 
 #include <assert.h>
@@ -254,7 +251,7 @@ parseHandshake (tr_handshake *    handshake,
   tr_torrent * tor;
   uint8_t peer_id[PEER_ID_LEN];
 
-  dbgmsg (handshake, "payload: need %d, got %zu",
+  dbgmsg (handshake, "payload: need %d, got %"TR_PRIuSIZE,
           HANDSHAKE_SIZE, evbuffer_get_length (inbuf));
 
   if (evbuffer_get_length (inbuf) < HANDSHAKE_SIZE)
@@ -565,7 +562,7 @@ readPadD (tr_handshake    * handshake,
 {
   const size_t needlen = handshake->pad_d_len;
 
-  dbgmsg (handshake, "pad d: need %zu, got %zu",
+  dbgmsg (handshake, "pad d: need %"TR_PRIuSIZE", got %"TR_PRIuSIZE,
           needlen, evbuffer_get_length (inbuf));
   if (evbuffer_get_length (inbuf) < needlen)
     return READ_LATER;
@@ -593,7 +590,7 @@ readHandshake (tr_handshake    * handshake,
   uint8_t reserved[HANDSHAKE_FLAGS_LEN];
   uint8_t hash[SHA_DIGEST_LENGTH];
 
-  dbgmsg (handshake, "payload: need %d, got %zu",
+  dbgmsg (handshake, "payload: need %d, got %"TR_PRIuSIZE,
           INCOMING_HANDSHAKE_LEN, evbuffer_get_length (inbuf));
 
   if (evbuffer_get_length (inbuf) < INCOMING_HANDSHAKE_LEN)
@@ -734,7 +731,7 @@ readYa (tr_handshake    * handshake,
   const uint8_t * secret;
   int len;
 
-  dbgmsg (handshake, "in readYa... need %d, have %zu",
+  dbgmsg (handshake, "in readYa... need %d, have %"TR_PRIuSIZE,
           KEY_LEN, evbuffer_get_length (inbuf));
   if (evbuffer_get_length (inbuf) < KEY_LEN)
     return READ_LATER;
@@ -884,7 +881,7 @@ readIA (tr_handshake    * handshake,
   struct evbuffer * outbuf;
   uint32_t crypto_select;
 
-  dbgmsg (handshake, "reading IA... have %zu, need %zu",
+  dbgmsg (handshake, "reading IA... have %"TR_PRIuSIZE", need %"TR_PRIuSIZE,
           evbuffer_get_length (inbuf), needlen);
   if (evbuffer_get_length (inbuf) < needlen)
     return READ_LATER;
@@ -961,7 +958,7 @@ readPayloadStream (tr_handshake    * handshake,
   int i;
   const size_t needlen = HANDSHAKE_SIZE;
 
-  dbgmsg (handshake, "reading payload stream... have %zu, need %zu",
+  dbgmsg (handshake, "reading payload stream... have %"TR_PRIuSIZE", need %"TR_PRIuSIZE,
           evbuffer_get_length (inbuf), needlen);
   if (evbuffer_get_length (inbuf) < needlen)
     return READ_LATER;
@@ -1176,7 +1173,7 @@ gotError (tr_peerIo  * io,
 **/
 
 static void
-handshakeTimeout (int foo UNUSED, short bar UNUSED, void * handshake)
+handshakeTimeout (evutil_socket_t foo UNUSED, short bar UNUSED, void * handshake)
 {
   tr_handshakeAbort (handshake);
 }
