@@ -4,7 +4,7 @@
  * It may be used under the GNU GPL versions 2 or 3
  * or any future license endorsed by Mnemosyne LLC.
  *
- * $Id: variant-benc.c 14241 2014-01-21 03:10:30Z jordan $
+ * $Id: variant-benc.c 14301 2014-06-29 01:41:33Z jordan $
  */
 
 #include <assert.h>
@@ -84,32 +84,42 @@ tr_bencParseStr (const uint8_t  * buf,
                  const uint8_t ** setme_str,
                  size_t *         setme_strlen)
 {
-  size_t len;
   const void * end;
-  char * endptr;
+  size_t len;
+  char * ulend;
+  const uint8_t * strbegin;
+  const uint8_t * strend;
 
   if (buf >= bufend)
-    return EILSEQ;
+    goto err;
 
   if (!isdigit (*buf))
-    return EILSEQ;
+    goto err;
 
   end = memchr (buf, ':', bufend - buf);
   if (end == NULL)
-    return EILSEQ;
+    goto err;
 
   errno = 0;
-  len = strtoul ((const char*)buf, &endptr, 10);
-  if (errno || endptr != end)
-    return EILSEQ;
+  len = strtoul ((const char*)buf, &ulend, 10);
+  if (errno || ulend != end)
+    goto err;
 
-  if ((const uint8_t*)end + 1 + len > bufend)
-    return EILSEQ;
+  strbegin = (const uint8_t*)end + 1;
+  strend = strbegin + len;
+  if ((strend<strbegin) || (strend>bufend))
+    goto err;
 
   *setme_end = (const uint8_t*)end + 1 + len;
   *setme_str = (const uint8_t*)end + 1;
   *setme_strlen = len;
   return 0;
+
+err:
+  *setme_end = NULL;
+  *setme_str = NULL;
+  *setme_strlen= 0;
+  return EILSEQ;
 }
 
 static tr_variant*
