@@ -1,13 +1,10 @@
 /*
- * This file Copyright (C) Mnemosyne LLC
+ * This file Copyright (C) 2008-2014 Mnemosyne LLC
  *
- * This file is licensed by the GPL version 2. Works owned by the
- * Transmission project are granted a special exemption to clause 2 (b)
- * so that the bulk of its code can remain under the MIT license.
- * This exemption does not extend to derived works not owned by
- * the Transmission project.
+ * It may be used under the GNU GPL versions 2 or 3
+ * or any future license endorsed by Mnemosyne LLC.
  *
- * $Id:$
+ * $Id: variant.c 14241 2014-01-21 03:10:30Z jordan $
  */
 
 #include <assert.h>
@@ -1283,7 +1280,7 @@ tr_variantFromBuf (tr_variant      * setme,
         err = tr_jsonParse (optional_source, buf, buflen, setme, setme_end);
         break;
 
-      case TR_VARIANT_FMT_BENC:
+      default /* TR_VARIANT_FMT_BENC */:
         err = tr_variantParseBenc (buf, ((const char*)buf)+buflen, setme, setme_end);
         break;
     }
