@@ -1,13 +1,10 @@
 /*
- * This file Copyright (C) Mnemosyne LLC
+ * This file Copyright (C) 2008-2014 Mnemosyne LLC
  *
- * This file is licensed by the GPL version 2. Works owned by the
- * Transmission project are granted a special exemption to clause 2 (b)
- * so that the bulk of its code can remain under the MIT license.
- * This exemption does not extend to derived works not owned by
- * the Transmission project.
+ * It may be used under the GNU GPL versions 2 or 3
+ * or any future license endorsed by Mnemosyne LLC.
  *
- * $Id: webseed.c 14134 2013-07-20 16:45:02Z jordan $
+ * $Id: webseed.c 14241 2014-01-21 03:10:30Z jordan $
  */
 
 #include <string.h> /* strlen () */
@@ -48,7 +45,7 @@ struct tr_webseed
   tr_peer              parent;
   tr_bandwidth         bandwidth;
   tr_session         * session;
-  tr_peer_callback   * callback;
+  tr_peer_callback     callback;
   void               * callback_data;
   tr_list            * tasks;
   struct event       * timer;
@@ -595,7 +592,7 @@ static const struct tr_peer_virtual_funcs my_funcs =
 tr_webseed*
 tr_webseedNew (struct tr_torrent  * tor,
                const char         * url,
-               tr_peer_callback   * callback,
+               tr_peer_callback     callback,
                void               * callback_data)
 {
   tr_webseed * w = tr_new0 (tr_webseed, 1);
