@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: Badger.m 13162 2012-01-14 17:12:04Z livings124 $
+ * $Id: Badger.m 13571 2012-10-15 02:12:44Z livings124 $
  *
  * Copyright (c) 2006-2012 Transmission authors and contributors
  *
@@ -47,10 +47,7 @@
 
 - (void) dealloc
 {
-    [[NSNotificationCenter defaultCenter] removeObserver: self];
-    
     [fHashes release];
-    
     [super dealloc];
 }
 
@@ -68,6 +65,8 @@
 
 - (void) addCompletedTorrent: (Torrent *) torrent
 {
+    NSParameterAssert(torrent != nil);
+    
     [fHashes addObject: [torrent hashString]];
     [[NSApp dockTile] setBadgeLabel: [NSString formattedUInteger: [fHashes count]]];
 }
