@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: CreatorWindowController.m 13352 2012-06-18 01:33:27Z livings124 $
+ * $Id: CreatorWindowController.m 13492 2012-09-10 02:37:29Z livings124 $
  *
  * Copyright (c) 2007-2012 Transmission authors and contributors
  *
@@ -206,6 +206,7 @@
         tr_metaInfoBuilderFree(fInfo);
     
     [fTimer invalidate];
+    [fTimer release];
     
     [super dealloc];
 }
@@ -544,12 +545,14 @@
     fOpenWhenCreated = [fOpenCheck state] == NSOnState; //need this since the check box might not exist, and value in prefs might have changed from another creator window
     [fDefaults setURL: [fLocation URLByDeletingLastPathComponent] forKey: @"CreatorLocationURL"];
     
+    if ([NSApp isOnLionOrBetter])
+        [[self window] setRestorable: NO];
+    
     [[NSNotificationCenter defaultCenter] postNotificationName: @"BeginCreateTorrentFile" object: fLocation userInfo: nil];
     tr_makeMetaInfo(fInfo, [[fLocation path] UTF8String], trackerInfo, [fTrackers count], [[fCommentView string] UTF8String], [fPrivateCheck state] == NSOnState);
     tr_free(trackerInfo);
     
-    fTimer = [NSTimer scheduledTimerWithTimeInterval: 0.1 target: self selector: @selector(checkProgress)
-                userInfo: nil repeats: YES];
+    fTimer = [[NSTimer scheduledTimerWithTimeInterval: 0.1 target: self selector: @selector(checkProgress) userInfo: nil repeats: YES] retain];
 }
 
 - (void) checkProgress
@@ -557,6 +560,7 @@
     if (fInfo->isDone)
     {
         [fTimer invalidate];
+        [fTimer release];
         fTimer = nil;
         
         NSAlert * alert;
