@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: InfoOptionsViewController.m 13660 2012-12-13 13:38:58Z livings124 $
+ * $Id: InfoOptionsViewController.m 13601 2012-10-29 22:44:12Z livings124 $
  *
  * Copyright (c) 2010-2012 Transmission authors and contributors
  *
@@ -62,7 +62,7 @@
     
     [[NSNotificationCenter defaultCenter] addObserver: self selector: @selector(setGlobalLabels) name: @"UpdateGlobalOptions" object: nil];
     [[NSNotificationCenter defaultCenter] addObserver: self selector: @selector(updateOptionsNotification:) name: @"UpdateOptionsNotification" object: nil];
-    /*
+    
     #warning remove when 10.7-only with auto layout
     const CGFloat padding = 6.0; //this shows as 8 in IB
     [fPrioritySectionLabel sizeToFit];
@@ -128,7 +128,7 @@
     [fPeersConnectLabel sizeToFit];
     NSRect peersConnectLabelFrame = [fPeersConnectLabel frame];
     peersConnectLabelFrame.origin.x = NSMaxX(peersConnectFrame) + padding;
-    [fPeersConnectLabel setFrame: peersConnectLabelFrame];*/
+    [fPeersConnectLabel setFrame: peersConnectLabelFrame];
 }
 
 - (void) dealloc
