@@ -1,13 +1,10 @@
 /*
- * This file Copyright (C) Mnemosyne LLC
+ * This file Copyright (C) 2009-2014 Mnemosyne LLC
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License version 2
- * as published by the Free Software Foundation.
+ * It may be used under the GNU GPL versions 2 or 3
+ * or any future license endorsed by Mnemosyne LLC.
  *
- * http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
- *
- * $Id: app.h 13869 2013-01-26 01:19:54Z jordan $
+ * $Id: app.h 14272 2014-05-09 02:32:28Z jordan $
  */
 
 #ifndef QTR_APP_H
@@ -37,7 +34,7 @@ class MyApp: public QApplication
 
   public:
     void raise ();
-    bool notify (const QString& title, const QString& body) const;
+    bool notifyApp (const QString& title, const QString& body) const;
 
   public:
     Favicons favicons;
