@@ -1,21 +1,19 @@
 /*
- * This file Copyright (C) Mnemosyne LLC
+ * This file Copyright (C) 2013-2014 Mnemosyne LLC
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License version 2
- * as published by the Free Software Foundation.
+ * It may be used under the GNU GPL versions 2 or 3
+ * or any future license endorsed by Mnemosyne LLC.
  *
- * http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
- *
- * $Id:$
+ * $Id: freespace-label.h 14241 2014-01-21 03:10:30Z jordan $
  */
 
 #ifndef QTR_FREESPACE_LABEL_H
 #define QTR_FREESPACE_LABEL_H
 
+#include <stdint.h>
+
 #include <QString>
 #include <QTimer>
-
 #include <QLabel>
 
 class Session;
