@@ -1,19 +1,17 @@
 /*
- * This file Copyright (C) Mnemosyne LLC
+ * This file Copyright (C) 2009-2014 Mnemosyne LLC
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License version 2
- * as published by the Free Software Foundation.
+ * It may be used under the GNU Public License v2 or v3 licenses,
+ * or any future license endorsed by Mnemosyne LLC.
  *
- * http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
- *
- * $Id: mainwin.cc 14150 2013-07-27 21:58:14Z jordan $
+ * $Id: mainwin.cc 14277 2014-05-18 19:47:02Z jordan $
  */
 
 #include <cassert>
 #include <iostream>
 
 #include <QtGui>
+#include <QCheckBox>
 #include <QProxyStyle>
 #include <QLabel>
 #include <QFileDialog>
@@ -83,22 +81,6 @@ TrMainWindow :: getStockIcon (const QString& name, int fallback)
   return icon;
 }
 
-namespace
-{
-  QSize calculateTextButtonSizeHint (QPushButton * button)
-  {
-    QStyleOptionButton opt;
-    opt.initFrom (button);
-    QString s (button->text ());
-    if (s.isEmpty ())
-      s = QString::fromLatin1 ("XXXX");
-    QFontMetrics fm = button->fontMetrics ();
-    QSize sz = fm.size (Qt::TextShowMnemonic, s);
-    return button->style ()->sizeFromContents (QStyle::CT_PushButton, &opt, sz, button).expandedTo (QApplication::globalStrut ());
-  }
-}
-
-
 TrMainWindow :: TrMainWindow (Session& session, Prefs& prefs, TorrentModel& model, bool minimized):
   myLastFullUpdateTime (0),
   mySessionDialog (new SessionDialog (session, prefs, this)),
@@ -106,7 +88,6 @@ TrMainWindow :: TrMainWindow (Session& session, Prefs& prefs, TorrentModel& mode
   myAboutDialog (new AboutDialog (this)),
   myStatsDialog (new StatsDialog (session, this)),
   myDetailsDialog (0),
-  myFileDialogOptionsCheck (0),
   myFilterModel (prefs),
   myTorrentDelegate (new TorrentDelegate (this)),
   myTorrentDelegateMin (new TorrentDelegateMin (this)),
@@ -118,6 +99,7 @@ TrMainWindow :: TrMainWindow (Session& session, Prefs& prefs, TorrentModel& mode
   myLastSendTime (0),
   myLastReadTime (0),
   myNetworkTimer (this),
+  myNetworkError (false),
   myRefreshTrayIconTimer (this),
   myRefreshActionSensitivityTimer (this)
 {
@@ -289,6 +271,8 @@ TrMainWindow :: TrMainWindow (Session& session, Prefs& prefs, TorrentModel& mode
   connect (&mySession, SIGNAL (dataReadProgress ()), this, SLOT (dataReadProgress ()));
   connect (&mySession, SIGNAL (dataSendProgress ()), this, SLOT (dataSendProgress ()));
   connect (&mySession, SIGNAL (httpAuthenticationRequired ()), this, SLOT (wrongAuthentication ()));
+  connect (&mySession, SIGNAL (error (QNetworkReply::NetworkError)), this, SLOT (onError (QNetworkReply::NetworkError)));
+  connect (&mySession, SIGNAL (errorMessage (const QString)), this, SLOT (errorMessage(const QString)));
 
   if (mySession.isServer ())
     {
@@ -723,7 +707,11 @@ TrMainWindow :: refreshTrayIcon ()
 
   myModel.getTransferSpeed (upSpeed, upCount, downSpeed, downCount);
 
-  if (!upCount && !downCount)
+  if (myNetworkError)
+    {
+      tip  = tr ("Network Error");
+    }
+  else if (!upCount && !downCount)
     {
       tip = tr ("Idle");
     }
@@ -1009,7 +997,8 @@ TrMainWindow :: toggleWindows (bool doShow)
 void
 TrMainWindow :: trayActivated (QSystemTrayIcon::ActivationReason reason)
 {
-  if (reason == QSystemTrayIcon::Trigger)
+  if ((reason == QSystemTrayIcon::Trigger) ||
+      (reason == QSystemTrayIcon::DoubleClick))
     {
       if (isMinimized ())
         toggleWindows (true);
@@ -1153,6 +1142,8 @@ TrMainWindow :: refreshPref (int key)
 ****
 ***/
 
+#define SHOW_OPTIONS_CHECKBOX_NAME "show-options-checkbox"
+
 void
 TrMainWindow :: newTorrent ()
 {
@@ -1163,24 +1154,29 @@ TrMainWindow :: newTorrent ()
 void
 TrMainWindow :: openTorrent ()
 {
-  QFileDialog * myFileDialog;
-  myFileDialog = new QFileDialog (this,
-                                  tr ("Open Torrent"),
-                                  myPrefs.getString (Prefs::OPEN_DIALOG_FOLDER),
-                                  tr ("Torrent Files (*.torrent);;All Files (*.*)"));
-  myFileDialog->setFileMode (QFileDialog::ExistingFiles);
-  myFileDialog->setAttribute (Qt::WA_DeleteOnClose);
+  QFileDialog * d;
+  d = new QFileDialog (this,
+                       tr ("Open Torrent"),
+                       myPrefs.getString (Prefs::OPEN_DIALOG_FOLDER),
+                       tr ("Torrent Files (*.torrent);;All Files (*.*)"));
+  d->setFileMode (QFileDialog::ExistingFiles);
+  d->setAttribute (Qt::WA_DeleteOnClose);
 
-  QCheckBox * button = new QCheckBox (tr ("Show &options dialog"));
-  button->setChecked (myPrefs.getBool (Prefs::OPTIONS_PROMPT));
-  QGridLayout * layout = dynamic_cast<QGridLayout*> (myFileDialog->layout ());
-  layout->addWidget (button, layout->rowCount (), 0, 1, -1, Qt::AlignLeft);
-  myFileDialogOptionsCheck = button;
+  QCheckBox * b = new QCheckBox (tr ("Show &options dialog"));
+  b->setChecked (myPrefs.getBool (Prefs::OPTIONS_PROMPT));
+  b->setObjectName (SHOW_OPTIONS_CHECKBOX_NAME);
+  auto l = dynamic_cast<QGridLayout*> (d->layout ());
+  if (l == nullptr)
+    {
+      l = new QGridLayout;
+      d->setLayout (l);
+    }
+  l->addWidget (b, l->rowCount(), 0, 1, -1, Qt::AlignLeft);
 
-  connect (myFileDialog, SIGNAL (filesSelected (const QStringList&)),
+  connect (d, SIGNAL (filesSelected (const QStringList&)),
            this, SLOT (addTorrents (const QStringList&)));
 
-  myFileDialog->show ();
+  d->show ();
 }
 
 void
@@ -1194,27 +1190,30 @@ TrMainWindow :: openURL ()
   if (!AddData::isSupported (str))
     str.clear ();
 
-  addTorrent (str);
+  addTorrent (str, true);
 }
 
 void
 TrMainWindow :: addTorrents (const QStringList& filenames)
 {
+  bool showOptions = myPrefs.getBool (Prefs::OPTIONS_PROMPT);
+
+  const QFileDialog * const fileDialog = qobject_cast<const QFileDialog*> (sender ());
+  if (fileDialog != NULL)
+    {
+      const QCheckBox * const b = fileDialog->findChild<const QCheckBox*> (SHOW_OPTIONS_CHECKBOX_NAME);
+      if (b != NULL)
+        showOptions = b->isChecked ();
+    }
+
   foreach (const QString& filename, filenames)
-    addTorrent (filename);
+    addTorrent (filename, showOptions);
 }
 
 void
-TrMainWindow :: addTorrent (const AddData& addMe)
+TrMainWindow :: addTorrent (const AddData& addMe, bool showOptions)
 {
-  bool show_options_dialog;
-
-  if (myFileDialogOptionsCheck)
-    show_options_dialog = myFileDialogOptionsCheck->isChecked ();
-  else
-    show_options_dialog = myPrefs.getBool (Prefs::OPTIONS_PROMPT);
-
-  if (show_options_dialog)
+  if (showOptions)
     {
       Options * o = new Options (mySession, myPrefs, addMe, this);
       o->show ();
@@ -1313,8 +1312,13 @@ TrMainWindow :: removeTorrents (const bool deleteFiles)
   msgBox.setStandardButtons (QMessageBox::Ok | QMessageBox::Cancel);
   msgBox.setDefaultButton (QMessageBox::Cancel);
   msgBox.setIcon (QMessageBox::Question);
-  /* hack needed to keep the dialog from being too narrow */
-  QGridLayout* layout = (QGridLayout*)msgBox.layout ();
+  // hack needed to keep the dialog from being too narrow
+  auto layout = dynamic_cast<QGridLayout*>(msgBox.layout());
+  if (layout == nullptr)
+    {
+      layout = new QGridLayout;
+      msgBox.setLayout (layout);
+    }
   QSpacerItem* spacer = new QSpacerItem (450, 0, QSizePolicy::Minimum, QSizePolicy::Expanding);
   layout->addItem (spacer, layout->rowCount (), 0, 1, layout->columnCount ());
 
@@ -1340,7 +1344,9 @@ TrMainWindow :: updateNetworkIcon ()
   const bool isReading = secondsSinceLastRead <= period;
   const char * key;
 
-  if (isSending && isReading)
+  if (myNetworkError)
+    key = "network-error";
+  else if (isSending && isReading)
     key = "network-transmit-receive";
   else if (isSending)
     key = "network-transmit";
@@ -1355,9 +1361,11 @@ TrMainWindow :: updateNetworkIcon ()
   const QString url = mySession.getRemoteUrl ().host ();
   if (!myLastReadTime)
     tip = tr ("%1 has not responded yet").arg (url);
-  else if (secondsSinceLastRead < 60)
+  else if (myNetworkError)
+    tip = tr (myErrorMessage.toLatin1 ().constData ());
+  else if (secondsSinceLastRead < 30)
     tip = tr ("%1 is responding").arg (url);
-  else if (secondsSinceLastRead < (60*10))
+  else if (secondsSinceLastRead < (60*2))
     tip = tr ("%1 last responded %2 ago").arg (url).arg (Formatter::timeToString (secondsSinceLastRead));
   else
     tip = tr ("%1 is not responding").arg (url);
@@ -1375,15 +1383,37 @@ TrMainWindow :: onNetworkTimer ()
 void
 TrMainWindow :: dataReadProgress ()
 {
+  if (!myNetworkError)
   myLastReadTime = time (NULL);
-  updateNetworkIcon ();
 }
 
 void
 TrMainWindow :: dataSendProgress ()
 {
   myLastSendTime = time (NULL);
-  updateNetworkIcon ();
+}
+
+void
+TrMainWindow :: onError (QNetworkReply::NetworkError code)
+{
+  const bool hadError = myNetworkError;
+  const bool haveError = (code != QNetworkReply::NoError)
+                      && (code != QNetworkReply::UnknownContentError);
+
+  myNetworkError = haveError;
+  refreshTrayIconSoon();
+  updateNetworkIcon();
+
+  // Refresh our model if we've just gotten a clean connection to the session.
+  // That way we can rebuild after a restart of transmission-daemon
+  if (hadError && !haveError)
+    myModel.clear();
+}
+
+void
+TrMainWindow :: errorMessage (const QString msg)
+{
+    myErrorMessage = msg;
 }
 
 void
