@@ -1,20 +1,16 @@
 /*
- * This file Copyright (C) Mnemosyne LLC
+ * This file Copyright (C) 2009-2014 Mnemosyne LLC
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License version 2
- * as published by the Free Software Foundation.
+ * It may be used under the GNU GPL versions 2 or 3
+ * or any future license endorsed by Mnemosyne LLC.
  *
- * http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
- *
- * $Id: mainwin.h 14002 2013-02-09 23:11:17Z jordan $
+ * $Id: mainwin.h 14241 2014-01-21 03:10:30Z jordan $
  */
 
 #ifndef MAIN_WINDOW_H
 #define MAIN_WINDOW_H
 
 #include <ctime>
-#include <QCheckBox>
 #include <QLineEdit>
 #include <QIcon>
 #include <QMainWindow>
@@ -24,10 +20,12 @@
 #include <QSystemTrayIcon>
 #include <QTimer>
 #include <QWidgetList>
+#include <QNetworkReply>
 
-extern "C" {
-    struct tr_variant;
-};
+extern "C"
+{
+  struct tr_variant;
+}
 
 #include "filters.h"
 #include "torrent-filter.h"
@@ -63,7 +61,6 @@ class TrMainWindow: public QMainWindow
     QDialog * myAboutDialog;
     QDialog * myStatsDialog;
     Details * myDetailsDialog;
-    QCheckBox * myFileDialogOptionsCheck;
     QSystemTrayIcon myTrayIcon;
     TorrentFilter myFilterModel;
     TorrentDelegate * myTorrentDelegate;
@@ -77,6 +74,7 @@ class TrMainWindow: public QMainWindow
     time_t myLastSendTime;
     time_t myLastReadTime;
     QTimer myNetworkTimer;
+    bool myNetworkError;
     QTimer myRefreshTrayIconTimer;
     QTimer myRefreshActionSensitivityTimer;
     QAction * myDlimitOffAction;
@@ -122,6 +120,8 @@ class TrMainWindow: public QMainWindow
     void toggleSpeedMode ();
     void dataReadProgress ();
     void dataSendProgress ();
+    void onError (QNetworkReply::NetworkError);
+    void errorMessage (const QString);
     void toggleWindows (bool doShow);
     void onSetPrefs ();
     void onSetPrefs (bool);
@@ -156,6 +156,7 @@ class TrMainWindow: public QMainWindow
     QLabel * myDownloadSpeedLabel;
     QLabel * myUploadSpeedLabel;
     QLabel * myNetworkLabel;
+    QString myErrorMessage;
 
   public slots:
     void startAll ();
@@ -171,11 +172,11 @@ class TrMainWindow: public QMainWindow
     void queueMoveDown ();
     void queueMoveBottom ();
     void reannounceSelected ();
-    void addTorrent (const AddData& addMe);
     void onNetworkTimer ();
 
   private:
     void clearSelection ();
+    void addTorrent (const AddData& addMe, bool showOptions);
 
   public slots:
     void setToolbarVisible (bool);
